elephant.test.test_statistics module — Elephant 0.5.0 documentation

# elephant.test.test_statistics module

Unit tests for the statistics module.

class `elephant.test.test_statistics.` `CV2TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_cv2_raise_error`()
  `test_cv2_with_list`()
  `test_cv2_with_plain_array`()
  `test_cv2_with_quantities`()

class `elephant.test.test_statistics.` `ComplexityPdfTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `tearDown`()
  `test_complexity_pdf`()

class `elephant.test.test_statistics.` `FanoFactorTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_fanofactor_array`()
  `test_fanofactor_array_same`()
  `test_fanofactor_empty`()
  `test_fanofactor_list`()
  `test_fanofactor_list_same`()
  `test_fanofactor_quantity`()
  `test_fanofactor_quantity_same`()
  `test_fanofactor_spiketrains`()
  `test_fanofactor_spiketrains_same`()

class `elephant.test.test_statistics.` `LVTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_lv_raise_error`()
  `test_lv_with_list`()
  `test_lv_with_plain_array`()
  `test_lv_with_quantities`()

class `elephant.test.test_statistics.` `RateEstimationTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_error_instantaneous_rate`()
  `test_instantaneous_rate_and_warnings`()
  `test_instantaneous_rate_spiketrainlist`()
  `test_rate_estimation_consistency`()

    Test, whether the integral of the rate estimation curve is (almost) equal to the number of spikes of the spike train.

class `elephant.test.test_statistics.` `TimeHistogramTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `tearDown`()
  `test_time_histogram`()
  `test_time_histogram_binary`()
  `test_time_histogram_output`()
  `test_time_histogram_tstart_tstop`()

class `elephant.test.test_statistics.` `isi_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_isi_with_plain_array_1d`()
  `test_isi_with_plain_array_2d_0`()
  `test_isi_with_plain_array_2d_1`()
  `test_isi_with_plain_array_2d_default`()
  `test_isi_with_quantities_1d`()
  `test_isi_with_spiketrain`()

class `elephant.test.test_statistics.` `isi_cv_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_cv_isi_regular_array_is_zero`()
  `test_cv_isi_regular_spiketrain_is_zero`()

class `elephant.test.test_statistics.` `mean_firing_rate_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_mean_firing_rate_with_plain_array_1d`()
  `test_mean_firing_rate_with_plain_array_1d_set_ends`()
  `test_mean_firing_rate_with_plain_array_2d_0`()
  `test_mean_firing_rate_with_plain_array_2d_1`()
  `test_mean_firing_rate_with_plain_array_2d_1_set_ends`()
  `test_mean_firing_rate_with_plain_array_2d_None`()
  `test_mean_firing_rate_with_plain_array_2d_default`()
  `test_mean_firing_rate_with_plain_array_3d_0`()
  `test_mean_firing_rate_with_plain_array_3d_1`()
  `test_mean_firing_rate_with_plain_array_3d_2`()
  `test_mean_firing_rate_with_plain_array_3d_None`()
  `test_mean_firing_rate_with_plain_array_and_units_start_stop_typeerror`()
  `test_mean_firing_rate_with_quantities_1d`()
  `test_mean_firing_rate_with_quantities_1d_set_ends`()
  `test_mean_firing_rate_with_spiketrain`()
  `test_mean_firing_rate_with_spiketrain_set_ends`()